@@ -46,7 +46,7 @@ def sync_customers():
     LOGS.logger.info("Sync customers from CRM -- START")
     products = Product.all()
     for product in products:
-        customers = core.get_customers_crm(product)
+        customers = core.get_customers_crm(product.name)
         for customer in customers:
             name = customer['ident'].lower()
             product_name = customer['produit_nom']
