@@ -99,9 +99,12 @@ def get_fuped_aiguiller():
 def get_customers_si(identifier=None, value=None):
     """Fetches fup-able customers in fup-service database."""
     if identifier and value:
-        sql = ("SELECT * FROM customer where {identifier}='{value}'")
+        sql = (
+            "SELECT * FROM customer where {}='{}'"
+            .format(identifier, value)
+        )
     else:
-        sql = ("SELECT * FROM customer")
+        sql = "SELECT * FROM customer"
     try:
         with records.Database(si_database_url()) as db:
             rows = db.query(sql)
